This package allows users to access the Water Stable Isotope Database in Peru. It includes 464 stations over Peru, updated until 2023, and provides an interactive map for exploring the spatial distribution of all the stations. Additionally, it offers features for technical validation and display temporal series for each station and department across Peru. For more information, users can refer to the package [GitHub](https://github.com/karoru23/WSI-PeruDB) page.

Users must create a new environment and install either the notebook version 6.5.2 or jupyterlab version 3.5.3

```bash
conda install notebook=6.5.2
```
or 

```bash
conda install jupyterlab=3.5.3
```
## Usage 

```python
import WSIPeruDB
```
# Display the spatial distribution of stable isotope stations
```
WSIPeruDB.generate_map()
```
# Get stations information
```
WSIPeruDB.department_information()
```
# Plot Linear Meteoric Water Line (LMWL)
```
WSIPeruDB.plot_lmwl()
```
# Display temporal series and histogram 
```
WSIPeruDB.analyze_temporal_series()
```
# Comparing dataset departments
```
WSIPeruDB.compare_departments()
```
# Download dataset information
```
WSIPeruDB.download_dataset()
```
# Download site information 
```
WSIPeruDB.download_site_information()
```

## Add or Download Data from WSIPeruDB package

Users must fill the request through this [Google Form](https://docs.google.com/forms/d/e/1FAIpQLSfikgyxrKKnKIHRzj7CgmXvYh3pv7Psu4D5wsl4ps1ZCZQCmw/viewform?vc=0&c=0&w=1&flr=0) either for add or download data from the WSI-PeruDB. This is necessary for us to maintain statistics about the database. 

## License

[MIT](https://choosealicense.com/licenses/mit/)